@@ -42,11 +42,21 @@ class MultiYearConfig(AnalysisConfig):
         my_file = os.path.join(self.dirout, self.name + ".h5")
         return my_file
 
+    @property
+    def groups(self):
+        """Get the multi year collection groups
+
+        Returns
+        -------
+        dict
+        """
+        return self._groups
+
     @property
     def group_names(self):
         """
         Returns
-        -------s
+        -------
         group_names : list
             List of group names
         """
