@@ -21,9 +21,9 @@ class TransmissionFeatures:
     """
     Class to handle Supply Curve Transmission features
     """
-    def __init__(self, trans_table, line_tie_in_cost=14000, line_cost=3667,
+    def __init__(self, trans_table, line_tie_in_cost=14000, line_cost=2279,
                  station_tie_in_cost=0, center_tie_in_cost=0,
-                 sink_tie_in_cost=14000, available_capacity=0.1,
+                 sink_tie_in_cost=1e9, avail_cap_frac=1,
                  line_limited=False):
         """
         Parameters
@@ -31,34 +31,38 @@ class TransmissionFeatures:
         trans_table : str | pandas.DataFrame
             Path to .csv or .json or DataFrame containing supply curve
             transmission mapping
-        line_tie_in_cost : float
-            Cost of connecting to a transmission line in $/MW
-        line_cost : float
-            Cost of building transmission line during connection in $/MW-mile
-        station_tie_in_cost : float
-            Cost of connecting to a substation in $/MW
-        center_tie_in_cost : float
-            Cost of connecting to a load center in $/MW
-        sink_tie_in_cost : float
+        line_tie_in_cost : float, optional
+            Cost of connecting to a transmission line in $/MW,
+            by default 14000
+        line_cost : float, optional
+            Cost of building transmission line during connection in $/MW-km,
+            by default 2279
+        station_tie_in_cost : float, optional
+            Cost of connecting to a substation in $/MW,
+            by default 0
+        center_tie_in_cost : float, optional
+            Cost of connecting to a load center in $/MW,
+            by default 0
+        sink_tie_in_cost : float, optional
             Cost of connecting to a synthetic load center (infinite sink)
-            in $/MW
-        available_capacity : float
-            Fraction of capacity that is available for connection
-        line_limited : bool
+            in $/MW, by default 1e9
+        avail_cap_frac : float, optional
+            Fraction of capacity that is available for connection, by default 1
+        line_limited : bool, optional
             Substation connection is limited by maximum capacity of the
-            attached lines, legacy method
+            attached lines, legacy method, by default False
         """
 
         logger.debug('Trans table input: {}'.format(trans_table))
         logger.debug('Line tie in cost: {} $/MW'.format(line_tie_in_cost))
-        logger.debug('Line cost: {} $/MW-mile'.format(line_cost))
+        logger.debug('Line cost: {} $/MW-km'.format(line_cost))
         logger.debug('Station tie in cost: {} $/MW'
                      .format(station_tie_in_cost))
         logger.debug('Center tie in cost: {} $/MW'.format(center_tie_in_cost))
         logger.debug('Synthetic load center tie in cost: {} $/MW'
                      .format(sink_tie_in_cost))
         logger.debug('Available capacity fraction: {}'
-                     .format(available_capacity))
+                     .format(avail_cap_frac))
         logger.debug('Line limited substation connections: {}'
                      .format(line_limited))
 
@@ -67,10 +71,9 @@ class TransmissionFeatures:
         self._station_tie_in_cost = station_tie_in_cost
         self._center_tie_in_cost = center_tie_in_cost
         self._sink_tie_in_cost = sink_tie_in_cost
-        self._available_capacity_frac = available_capacity
+        self._avail_cap_frac = avail_cap_frac
 
         self._features = self._get_features(trans_table)
-        self._check_feature_dependencies()
 
         self._feature_gid_list = list(self._features.keys())
         self._available_mask = np.ones(
@@ -148,6 +151,14 @@ class TransmissionFeatures:
             logger.error(ex)
             raise
 
+        trans_table = \
+            trans_table.rename(columns={'trans_line_gid': 'trans_gid',
+                                        'trans_gids': 'trans_line_gids'})
+
+        if 'dist_mi' in trans_table:
+            trans_table = trans_table.rename(columns={'dist_mi': 'dist_km'})
+            trans_table['dist_km'] *= 1.60934
+
         return trans_table
 
     def _features_from_table(self, trans_table):
@@ -171,8 +182,8 @@ class TransmissionFeatures:
 
         features = {}
 
-        cap_frac = self._available_capacity_frac
-        trans_features = trans_table.groupby('trans_line_gid').first()
+        cap_frac = self._avail_cap_frac
+        trans_features = trans_table.groupby('trans_gid').first()
 
         for gid, feature in trans_features.iterrows():
             name = feature['category'].lower()
@@ -182,7 +193,7 @@ class TransmissionFeatures:
                 feature_dict['avail_cap'] = feature['ac_cap'] * cap_frac
 
             elif name == 'substation':
-                feature_dict['lines'] = json.loads(feature['trans_gids'])
+                feature_dict['lines'] = json.loads(feature['trans_line_gids'])
 
             elif name == 'loadcen':
                 feature_dict['avail_cap'] = feature['ac_cap'] * cap_frac
@@ -224,7 +235,7 @@ class TransmissionFeatures:
 
         return features
 
-    def _check_feature_dependencies(self):
+    def check_feature_dependencies(self):
         """Check features for dependencies that are missing and raise error."""
         missing = {}
         for gid, feature_dict in self._features.items():
@@ -242,7 +253,7 @@ class TransmissionFeatures:
             raise RuntimeError(emsg)
 
     @staticmethod
-    def _calc_cost(distance, line_cost=3667, tie_in_cost=0,
+    def _calc_cost(distance, line_cost=2279, tie_in_cost=0,
                    transmission_multiplier=1):
         """
         Compute transmission cost in $/MW
@@ -250,13 +261,14 @@ class TransmissionFeatures:
         Parameters
         ----------
         distance : float
-            Distance to feature in miles
-        line_cost : float
-            Cost of tranmission lines in $/MW-mile
-        tie_in_cost : float
-            Cost to connect to feature in $/MW
-        line_multiplier : float
-            Multiplier for region specific line cost increases
+            Distance to feature in kms
+        line_tie_in_cost : float, optional
+            Cost of connecting to a transmission line in $/MW,
+            by default 14000
+        tie_in_cost : float, optional
+            Cost to tie in line to feature in $/MW, by default 0
+        tranmission_multiplier : float, optional
+            Multiplier for region specific line cost increases, by default 1
 
         Returns
         -------
@@ -306,7 +318,7 @@ class TransmissionFeatures:
         -------
         avail_cap : float
             Available capacity = capacity * available fraction
-            default = 10%
+            default = 100%
         """
 
         feature = self[gid]
@@ -515,7 +527,7 @@ class TransmissionFeatures:
         gid : int
             Feature gid to connect to
         distance : float
-            Distance to feature in miles
+            Distance to feature in kms
         line_multiplier : float
             Multiplier for region specific line cost increases
         capacity : float
@@ -555,7 +567,7 @@ class TransmissionFeatures:
         return cost
 
     @classmethod
-    def feature_capacity(cls, trans_table, available_capacity=0.1):
+    def feature_capacity(cls, trans_table, avail_cap_frac=1):
         """
         Compute available capacity for all features
 
@@ -563,19 +575,8 @@ class TransmissionFeatures:
         ----------
         trans_table : str | pandas.DataFrame
             Path to .csv or .json containing supply curve transmission mapping
-        line_tie_in_cost : float
-            Cost of connecting to a transmission line in $/MW
-        line_cost : float
-            Cost of building transmission line during connection in $/MW-mile
-        station_tine_in_cost : float
-            Cost of connecting to a substation in $/MW
-        center_tie_in_cost : float
-            Cost of connecting to a load center in $/MW
-        center_tie_in_cost : float
-            Cost of connecting to a synthetic load center (infinite sink)
-            in $/MW
-        available_capacity : float
-            Fraction of capacity that is available for connection
+        avail_cap_frac : float, optional
+            Fraction of capacity that is available for connection, by default 1
 
         Returns
         -------
@@ -583,7 +584,7 @@ class TransmissionFeatures:
             Available Capacity for each transmission feature
         """
         try:
-            feature = cls(trans_table, available_capacity=available_capacity)
+            feature = cls(trans_table, avail_cap_frac=avail_cap_frac)
 
             feature_cap = {}
             for gid, _ in feature._features.items():
@@ -595,7 +596,7 @@ class TransmissionFeatures:
 
         feature_cap = pd.Series(feature_cap)
         feature_cap.name = 'avail_cap'
-        feature_cap.index.name = 'trans_line_gid'
+        feature_cap.index.name = 'trans_gid'
         feature_cap = feature_cap.to_frame().reset_index()
 
         return feature_cap
@@ -627,12 +628,12 @@ class TransmissionCosts(TransmissionFeatures):
         features = {}
 
         if 'avail_cap' not in trans_table:
-            kwargs = {'available_capacity': self._available_capacity_frac}
+            kwargs = {'avail_cap_frac': self._avail_cap_frac}
             fc = TransmissionFeatures.feature_capacity(trans_table,
                                                        **kwargs)
-            trans_table = trans_table.merge(fc, on='trans_line_gid')
+            trans_table = trans_table.merge(fc, on='trans_gid')
 
-        trans_features = trans_table.groupby('trans_line_gid').first()
+        trans_features = trans_table.groupby('trans_gid').first()
         for gid, feature in trans_features.iterrows():
             name = feature['category'].lower()
             feature_dict = {'type': name, 'avail_cap': feature['avail_cap']}
@@ -653,16 +654,16 @@ class TransmissionCosts(TransmissionFeatures):
         -------
         avail_cap : float
             Available capacity = capacity * available fraction
-            default = 10%
+            default = 100%
         """
 
         return self[gid]['avail_cap']
 
     @classmethod
     def feature_costs(cls, trans_table, capacity=None, line_tie_in_cost=14000,
-                      line_cost=3667, station_tie_in_cost=0,
-                      center_tie_in_cost=0, sink_tie_in_cost=14000,
-                      available_capacity=0.1, line_limited=False):
+                      line_cost=2279, station_tie_in_cost=0,
+                      center_tie_in_cost=0, sink_tie_in_cost=1e9,
+                      avail_cap_frac=1, line_limited=False):
         """
         Compute costs for all connections in given transmission table
 
@@ -673,22 +674,26 @@ class TransmissionCosts(TransmissionFeatures):
         capacity : float
             Capacity needed in MW, if None DO NOT check if connection is
             possible
-        line_tie_in_cost : float
-            Cost of connecting to a transmission line in $/MW
-        line_cost : float
-            Cost of building transmission line during connection in $/MW-mile
-        station_tine_in_cost : float
-            Cost of connecting to a substation in $/MW
-        center_tie_in_cost : float
-            Cost of connecting to a load center in $/MW
-        center_tie_in_cost : float
+        line_tie_in_cost : float, optional
+            Cost of connecting to a transmission line in $/MW,
+            by default 14000
+        line_cost : float, optional
+            Cost of building transmission line during connection in $/MW-km,
+            by default 2279
+        station_tie_in_cost : float, optional
+            Cost of connecting to a substation in $/MW,
+            by default 0
+        center_tie_in_cost : float, optional
+            Cost of connecting to a load center in $/MW,
+            by default 0
+        sink_tie_in_cost : float, optional
             Cost of connecting to a synthetic load center (infinite sink)
-            in $/MW
-        available_capacity : float
-            Fraction of capacity that is available for connection
-        line_limited : bool
+            in $/MW, by default 1e9
+        avail_cap_frac : float, optional
+            Fraction of capacity that is available for connection, by default 1
+        line_limited : bool, optional
             Substation connection is limited by maximum capacity of the
-            attached lines, legacy method
+            attached lines, legacy method, by default False
 
         Returns
         -------
@@ -703,14 +708,14 @@ class TransmissionCosts(TransmissionFeatures):
                           station_tie_in_cost=station_tie_in_cost,
                           center_tie_in_cost=center_tie_in_cost,
                           sink_tie_in_cost=sink_tie_in_cost,
-                          available_capacity=available_capacity,
+                          avail_cap_frac=avail_cap_frac,
                           line_limited=line_limited)
 
             costs = []
             for _, row in trans_table.iterrows():
                 tm = row.get('transmission_multiplier', 1)
-                costs.append(feature.cost(row['trans_line_gid'],
-                                          row['dist_mi'], capacity=capacity,
+                costs.append(feature.cost(row['trans_gid'],
+                                          row['dist_km'], capacity=capacity,
                                           transmission_multiplier=tm))
         except Exception:
             logger.exception("Error computing costs for all connections in {}"
