@@ -12,6 +12,7 @@ from scipy import stats
 from warnings import warn
 
 from reV.econ.economies_of_scale import EconomiesOfScale
+from reV.econ.utilities import lcoe_fcr
 from reV.handlers.exclusions import ExclusionLayers
 from reV.supply_curve.points import GenerationSupplyCurvePoint
 from reV.utilities.exceptions import (EmptySupplyCurvePointError,
@@ -34,7 +35,8 @@ class SupplyCurvePointSummary(GenerationSupplyCurvePoint):
                  res_class_dset=None, res_class_bin=None, excl_area=0.0081,
                  power_density=None, cf_dset='cf_mean-means',
                  lcoe_dset='lcoe_fcr-means', h5_dsets=None, resolution=64,
-                 exclusion_shape=None, close=False, friction_layer=None):
+                 exclusion_shape=None, close=False, friction_layer=None,
+                 recalc_lcoe=True):
         """
         Parameters
         ----------
@@ -92,6 +94,12 @@ class SupplyCurvePointSummary(GenerationSupplyCurvePoint):
         friction_layer : None | FrictionMask
             Friction layer with scalar friction values if valid friction inputs
             were entered. Otherwise, None to not apply friction layer.
+        recalc_lcoe : bool
+            Flag to re-calculate the LCOE from the multi-year mean capacity
+            factor and annual energy production data. This requires several
+            datasets to be aggregated in the h5_dsets input: system_capacity,
+            fixed_charge_rate, capital_cost, fixed_operating_cost,
+            and variable_operating_cost.
         """
 
         self._res_class_dset = res_class_dset
@@ -106,6 +114,7 @@ class SupplyCurvePointSummary(GenerationSupplyCurvePoint):
         self._pd_obj = None
         self._power_density = power_density
         self._friction_layer = friction_layer
+        self._recalc_lcoe = recalc_lcoe
 
         super().__init__(gid, excl, gen, tm_dset, gen_index,
                          excl_dict=excl_dict,
@@ -206,8 +215,31 @@ class SupplyCurvePointSummary(GenerationSupplyCurvePoint):
         mean_lcoe : float | None
             Mean LCOE value for the non-excluded data.
         """
+
         mean_lcoe = None
-        if self.lcoe_data is not None:
+
+        # prioritize the calculation of lcoe explicitly from the multi year
+        # mean CF (the lcoe re-calc will still happen if mean_cf is a single
+        # year CF, but the output should be identical to the original LCOE and
+        # so is not consequential).
+        if self._recalc_lcoe:
+            required = ('fixed_charge_rate', 'capital_cost',
+                        'fixed_operating_cost', 'variable_operating_cost',
+                        'system_capacity')
+            if self.mean_h5_dsets_data is not None:
+                if all(k in self.mean_h5_dsets_data for k in required):
+                    aep = (self.mean_h5_dsets_data['system_capacity']
+                           * self.mean_cf * 8760)
+                    mean_lcoe = lcoe_fcr(
+                        self.mean_h5_dsets_data['fixed_charge_rate'],
+                        self.mean_h5_dsets_data['capital_cost'],
+                        self.mean_h5_dsets_data['fixed_operating_cost'],
+                        aep,
+                        self.mean_h5_dsets_data['variable_operating_cost'])
+
+        # alternative if lcoe was not able to be re-calculated from
+        # multi year mean CF
+        if mean_lcoe is None and self.lcoe_data is not None:
             mean_lcoe = self.exclusion_weighted_mean(self.lcoe_data)
 
         return mean_lcoe
@@ -670,6 +702,7 @@ class SupplyCurvePointSummary(GenerationSupplyCurvePoint):
         eos = EconomiesOfScale(cap_cost_scale, summary)
         summary['raw_lcoe'] = eos.raw_lcoe
         summary['mean_lcoe'] = eos.scaled_lcoe
+        summary['capital_cost_scalar'] = eos.capital_cost_scalar
 
         return summary
 
@@ -681,7 +714,7 @@ class SupplyCurvePointSummary(GenerationSupplyCurvePoint):
                   cf_dset='cf_mean-means', lcoe_dset='lcoe_fcr-means',
                   h5_dsets=None, resolution=64, exclusion_shape=None,
                   close=False, friction_layer=None, args=None,
-                  data_layers=None, cap_cost_scale=None):
+                  data_layers=None, cap_cost_scale=None, recalc_lcoe=True):
         """Get a summary dictionary of a single supply curve point.
 
         Parameters
@@ -752,6 +785,12 @@ class SupplyCurvePointSummary(GenerationSupplyCurvePoint):
             value to multiply the capital cost by. Independent variables in
             the equation should match the names of the columns in the reV
             supply curve aggregation table.
+        recalc_lcoe : bool
+            Flag to re-calculate the LCOE from the multi-year mean capacity
+            factor and annual energy production data. This requires several
+            datasets to be aggregated in the h5_dsets input: system_capacity,
+            fixed_charge_rate, capital_cost, fixed_operating_cost,
+            and variable_operating_cost.
 
         Returns
         -------
@@ -770,7 +809,9 @@ class SupplyCurvePointSummary(GenerationSupplyCurvePoint):
                   "resolution": resolution,
                   "exclusion_shape": exclusion_shape,
                   "close": close,
-                  'friction_layer': friction_layer}
+                  'friction_layer': friction_layer,
+                  'recalc_lcoe': recalc_lcoe,
+                  }
 
         with cls(gid, excl_fpath, gen_fpath, tm_dset, gen_index,
                  **kwargs) as point:
